@@ -1,6 +1,9 @@
 """ representation and processing of an ANSI stream into an 'ast' of sorts
 such that it can be rendered
 """
+from __future__ import annotations
+from typing import Optional
+
 from ansitoimg.utils import ansiColourToRGB, findLen
 
 
@@ -17,15 +20,16 @@ class AnsiBlock():
 	- underline
 	- crossed out
 	"""
-	def __init__(self, text, position, bgColour=None, fgColour=None, bold=False,
-	italic=False, underline=False, crossedOut=False):
+	def __init__(self, text: str, position: tuple[int, int],
+	bgColour: Optional[str]=None, fgColour: Optional[str]=None, bold: bool=False,
+	italic: bool=False, underline: bool=False, crossedOut: bool=False):
 		"""Constructor
 
 		Args:
-			text (string): text content to render
+			text (str): text content to render
 			position (int, int): x, y tuple to store the absolute offset in chars
-			bgColour (string, optional): background colour. Defaults to None.
-			fgColour (string, optional): foreground colour. Defaults to None.
+			bgColour (str, optional): background colour. Defaults to None.
+			fgColour (str, optional): foreground colour. Defaults to None.
 			bold (bool, optional): is text bold?. Defaults to False.
 			italic (bool, optional): is text italic?. Defaults to False.
 			underline (bool, optional): is text underlined?. Defaults to False.
@@ -60,11 +64,12 @@ class AnsiBlocks():
 	- height
 	- char pointer
 	"""
-	def __init__(self, ansiText):
+	def __init__(self, ansiText: str, wide: bool=True):
 		"""Constructor
 
 		Args:
-			ansiText (string): ANSI text stream to process
+			ansiText (str): ANSI text stream to process
+			wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
 		"""
 		# text to parse
 		self.ansiText = ansiText
@@ -85,33 +90,36 @@ class AnsiBlocks():
 		self.height = 1
 		self.pointer = 0
 
+		self.maxWidth = 89 if wide else 49
+
 	def process(self):
 		""" process the ANSI text into a series of ANSI blocks """
 		while self.pointer < len(self.ansiText):
 			# process sgi codes
 			if self.ansiText[self.pointer] == "\033":
 				self.processSgi()
+
 			# if not an sgi code then add to the text buffer
 			else:
 				self.textBuffer.append(self.ansiText[self.pointer])
 				self.pointer += 1
 			# if there is a 'closing' sgi code, create an ANSI block
-			if len(self.sgiBuffer) > 0 and self.sgiBuffer[-1] in ("\033[0m", "\033[21m",
+			if len(self.sgiBuffer) > 0 and self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[21m",
 			"\033[23m", "\033[24m", "\033[29m", "\033[39m", "\033[49m"):
 				self.processCloseSgi()
 		# create an ANSI block out of anythin left over
 		if len(self.textBuffer) > 0:
 			self.setAnsiBlocks("".join(self.textBuffer))
 
-	def setAnsiBlocks(self, text):
+	def setAnsiBlocks(self, text: str):
 		"""create a series of ANSI blocks from the text buffer and other attributes
 
 		Args:
-			text (string): text from the buffer
+			text (str): text from the buffer
 		"""
 		writeTxt = []
 		for char in text:
-			if char == "\n" or self.absX + findLen(writeTxt) > 59: # triggers a newline
+			if char == "\n" or self.absX + findLen(writeTxt) > self.maxWidth: # triggers a newline
 				self.ansiBlocks.append(
 				AnsiBlock("".join(writeTxt), (self.absX, self.absY), self.bgColour,
 				self.fgColour, self.bold, self.italic))
@@ -142,15 +150,16 @@ class AnsiBlocks():
 		self.pointer += 1
 		# set attributes based on the sgi flag
 		sgiFlag = "".join(sgiChar)
-		if sgiFlag == "\033[1m":
+		if sgiFlag in ("\033[1m", "\033[01m"):
 			self.bold = True
-		elif sgiFlag in ("\033[2m", "\033[5m", "\033[6m", "\033[7m", "\033[8m", ):
+		elif sgiFlag in ("\033[2m", "\033[5m", "\033[6m", "\033[7m", "\033[8m",
+		"\033[02m", "\033[05m", "\033[06m", "\033[07m", "\033[08m", ):
 			pass
-		elif sgiFlag == "\033[3m":
+		elif sgiFlag in ("\033[3m", "\033[03m"):
 			self.italic = True
-		elif sgiFlag == "\033[4m":
+		elif sgiFlag in ("\033[4m", "\033[04m"):
 			self.underline = True
-		elif sgiFlag == "\033[9m":
+		elif sgiFlag in ("\033[9m", "\033[09m"):
 			self.crossedOut = True
 		elif sgiFlag != "\033[39m" and sgiFlag.startswith(
 		"\033[3") or sgiFlag.startswith("\033[9"):
@@ -165,17 +174,17 @@ class AnsiBlocks():
 		reset any attributes that need setting """
 		self.setAnsiBlocks("".join(self.textBuffer))
 		# reset as per sgi code
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[49m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[49m"):
 			self.bgColour = None
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[39m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[39m"):
 			self.fgColour = None
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[21m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[21m"):
 			self.bold = False
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[23m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[23m"):
 			self.italic = False
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[24m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[24m"):
 			self.underline = False
-		if self.sgiBuffer[-1] in ("\033[0m", "\033[29m"):
+		if self.sgiBuffer[-1] in ("\033[0m", "\033[00m", "\033[29m"):
 			self.crossedOut = False
 		self.textBuffer = []
 		self.sgiBuffer = []
